@@ -82,13 +82,13 @@ class I2AOauth2Client:
         else:
             raise I2AOauth2ClientException(data=response.json())
 
-    def get_token(self, username, password):
+    def get_token(self, email, password):
         url = self._get_full_url('auth/token/')
         data = {
             "client_id": self.client_id,
             "client_secret": self.client_secret,
             "grant_type": "password",
-            "username": username,
+            "username": email,
             "password": password
         }
         response = requests.post(url, json=data, headers=self.headers)
